@@ -592,6 +592,14 @@ module.exports = function (grunt) {
       ]);
   });
 
+  grunt.registerTask('releaseStoreApk', [
+    'reinstallPlugins:production',
+    'compress:production',
+    'shell:buildRelease',
+    'shell:jarsigner',
+    'shell:zipalign'
+  ]);
+
   /* Those task are use to install/remove/reinstall plugin which rely on --variables */
   grunt.registerTask('installPluginsWithVariable', function() {
     var base = this.args[0];
