@@ -18,5 +18,5 @@ packageJSON.cordovaPlugins.forEach(function (plugin) {
   });
 });
 
-exec('grunt reinstallPlugins:development --force'); // --force cuz uninstall plugin might fail if it hasn't been installed
+exec('grunt reinstallPlugins:development --force'); // --force cuz uninstall plugin might fail if a plugin hasn't been installed.
 
