@@ -2,16 +2,9 @@
 angular.module('{{APP_NAME}}.services').factory('UsernameAuthService', [
   '$q',
   function ($q) {
-    var getPlugin = function() {
-      var q = $q.defer();
-      $ionicPlatform.ready(function () {
-        q.resolve($cordovaFacebook);
-      });
-      return q.promise;
-    }
     var login = function (userData) {
       var q = $q.defer();
-      q.resolve(userData);²
+      q.resolve(userData);
       return q.promise;
     };
     var dataService = {
