@@ -2,7 +2,7 @@
 module.exports = {
   ask: function(self) {
     var done = self.async();
-    this.prompt([{
+    self.prompt([{
       type: 'confirm',
       name: 'flurry',
       message: 'Would you like to use Flurry Analytics?',
