@@ -10,7 +10,8 @@ module.exports = {
   push: require('./push.js'),
   analytics: require('./analytics.js'),
   models: require('./models.js'),
-  grunt: require('./gruntfile.js')
+  grunt: require('./gruntfile.js'),
+  constants: require('./constants.js')
 };
 
 function mergeCollections(arr1, arr2, prop) {
