@@ -1,7 +1,7 @@
 
 var chalk = require('chalk');
 
-var prompt: [{
+var prompt = [{
   type: 'checkbox',
   name: 'plugins',
   message: 'Which Cordova plugins would you like to include?',
